Skip to contents

Cell line information from DepMap Public 24Q4.

Format

Table

Loading

data.table::fread(system.file("depmap_data/Model.csv.gz", package = "gDRtestData"))

Description

  • Rows: Cell line identifiers

  • Columns: Metadata columns (see below)

  • Values: Cell line annotations and donor demographics

Columns:

ModelID

Unique cell line identifier (ACH-XXXXX format)

CCLEName

Cell line name from Cancer Cell Line Encyclopedia (CCLE)

CellLineName

Common cell line name (e.g., "A375", "HCT-116")

DepmapModelType

Abbreviated ID for model type. For cancer models, from Oncotree; for other disease types, generated by DepMap

OncotreeLineage

Primary cancer lineage classification (from Oncotree for cancer models, generated by DepMap for others)

OncotreePrimaryDisease

Primary disease of model (from Oncotree for cancer models, generated by DepMap for others)

OncotreeSubtype

Subtype classification of model (from Oncotree for cancer models, generated by DepMap for others)

OncotreeCode

Oncotree code for cancer models; left blank if no corresponding code exists

PrimaryOrMetastasis

Site of tumor origin (Primary/Metastatic/Recurrence/Other/Unknown)

Age

Age at time of tissue sampling

AgeCategory

Age category at time of sampling (Adult/Pediatric/Fetus/Unknown)

Sex

Sex at time of sampling (Female/Male/Unknown)

PatientRace

Patient/clinical indicated race (not derived)

Details

Downloaded May 26, 2026 from DepMap Portal (version 24Q4).

Citation: 24Q4 DepMap Release, including CRISPR Screens, PRISM Drug Screens, Copy Number, Mutation, Expression, and Fusions DepMap, Broad (2024). DepMap 24Q4 Public. Figshare+. Dataset. https://doi.org/10.25452/figshare.plus.27993248.v1